@@ -2,7 +2,7 @@ package
     slot;
 use strict;
 use warnings;
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 require XSLoader;
 XSLoader::load('slot', $VERSION);
 1;
@@ -200,6 +200,15 @@ Reset slot value(s) to undef and remove watchers by numeric index.
 
 Returns a list of all defined slot names.
 
+=head2 slot::exists
+
+    if (slot::exists('config')) {
+        # slot is defined
+    }
+
+Check if a slot with the given name has been defined. Returns true if
+the slot exists, false otherwise.
+
 =head1 THREAD SAFETY
 
 For thread-safe data sharing, store C<threads::shared> variables in slots:
